#
# spec file for package kdbg
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           kdbg
Version:        3.1.0
Release:        1.4
Summary:        Graphical User Interface for GDB
License:        GPL-2.0-or-later
URL:            https://www.kdbg.org/
Source0:        https://github.com/j6t/kdbg/archive/refs/tags/%{name}-%{version}.tar.gz
BuildRequires:  cmake >= 3.3
BuildRequires:  extra-cmake-modules
BuildRequires:  fdupes
BuildRequires:  kf5-filesystem
BuildRequires:  cmake(KF5Config)
BuildRequires:  cmake(KF5I18n)
BuildRequires:  cmake(KF5IconThemes)
BuildRequires:  cmake(KF5WindowSystem)
BuildRequires:  cmake(KF5XmlGui)
BuildRequires:  cmake(Qt5Core)
BuildRequires:  cmake(Qt5Widgets)
Requires:       gdb
Suggests:       kdbg-doc = %{version}

%description
KDbg is a graphical user interface for GDB, the GNU debugger. It
provides an intuitive interface for setting breakpoints, inspecting
variables, and stepping through code.

%package doc
Summary:        Documentation for kdbg
Requires:       kdbg = %{version}

%description doc
This package provides the documentation for kdbg

%lang_package

%prep
%autosetup -p1 -n kdbg-kdbg-%{version}

%build
%cmake_kf5 -d build
%make_jobs

%install
%kf5_makeinstall -C build

%fdupes %{buildroot}

%find_lang %{name} --all-name

%{kf5_find_htmldocs}

%files lang -f %{name}.lang

%files
%license COPYING
%doc README ReleaseNotes-*
%config %{_kf5_configdir}/kdbgrc
%doc %lang(en) %{_kf5_htmldir}/en/kdbg
%{_kf5_bindir}/kdbg
%{_kf5_sharedir}/kdbg/
%{_kf5_kxmlguidir}/kdbg/
%{_kf5_iconsdir}/hicolor/
%{_kf5_applicationsdir}/kdbg.desktop

%changelog
* Fri Mar 22 2024 Christophe Marin <christophe@krop.fr>
- Update to 3.1.0
  Enhancements:
  * The disassembly flavor to be used for the display of
    disassembled code can be selected. The setting is per
    program. Thanks to Petros Siligkounas.
  * The break ("pulse") button now shows help text.
  Bug Fixes:
  * Icons of certain actions were missing, which has been fixed,
    most importantly of the Open Executable action
  * The value parser no longer chokes on references to incomplete
    types, which caused a truncated list in the Variables window.
  Development Support:
  * Many modernizations took place so that the build procedure
    now reports far fewer deprecation warnings.
  Deprecation Notice:
  * XSL debugging support is no longer maintained and is now
    deprecated. It will be removed in a future release.
* Mon Jan 13 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 3.0.1
  * Use a color of the selected line with better contrast depending on
    the UI theme being used
  * Recognize parameter names of variadic function templates.
  * Show char16_t and char32_t string values.
  * No longer install individual frame images of the pulse animation.
* Tue Dec 12 2017 christophe@krop.fr
- Update to 3.0.0
  * XSL debugging support is no longer maintained and is now deprecated.
  * Ported to KDE Frameowork 5
  * The memory dump window shows an ASCII representation when the display
    is set to "hexadecimal"
  * The displayed memory dump is extended automatically when the window is
    scrolled to the end of the currently visible dump
  * Source code tab windows can be closed with a close button
  * When the current line is updated due to a debugger step command, it is
    centered in the window
  * Group headers in the Registers window use the available window width.
* Tue Aug 15 2017 wbauer@tmo.at
- Update to 2.9.1:
  * Enhancements
  - Display QString values in programs based on Qt5.
  - Show truncated structure values in the popup of the Expression window.
  * Bug fixes
  - Fix that the View menu entries can show and hide docking windows.
* Sat Jan 21 2017 wbauer@tmo.at
- Update to 2.9.0:
  * Enhancements
  - A brand new application icon.
  - There is now a command to detach from a program being debugged.
    Thanks to Daniel Black.
  - Pointing on a variable shows a value in a popup in more cases.
    Thanks to Max Tomilov.
  - C++11 keywords are highlighted. Thanks to Michael Hansen.
  * Bug fixes
  - Line breaks of status bar messages produced by GDB are now trimmed
    to avoid that the text is only visible partially. Fix by Gilles Allard.
  - (Action and application) icons are installed in an application neutral
    location because the launcher menu of modern KDE desktops does not show
    the icon otherwise.
  - Fixed a typo in the pretty-printer of std::vector<>.
- Drop susepatches.diff, applied upstream
* Thu Dec  8 2016 fabian@ritter-vogt.de
- Revert kde4_runtime_requires change
* Tue Nov 29 2016 olaf@aepfle.de
- Expand macro kde4_runtime_requires only when its available
  to fix quilt setup
* Sun Oct 23 2016 wbauer@tmo.at
- Update to 2.5.6:
  * A popup shows the complete value of variables.
  * The values printed by GDB for uninitialized references and
    pointer-to-member variables no longer truncate the variable list.
  * A few more C++ keywords are now highlighted.
  * The CMakeLists.txt file was adjusted for newer cmake.
- Removed fix-build-with-cmake-3_4_3.diff, it's no longer necessary
* Wed Feb 24 2016 cgiboudeaux@gmx.com
- Add fix-build-with-cmake-3_4_3.diff. Include the files containing
  the functions used by the CMake code.
* Tue Mar  3 2015 wbauer@tmo.at
- Update to 2.5.5:
  * A crash when the hotkey settings are changed was fixed.
  * The animation button was regenerated to avoid a crash with modern Qt.
    Thanks to Armin Felder for the initial fix.
  * Pretty-printers and GDB Python extensions were disabled, because they
    would interfere with the output parser.
  * Recent GDBs do not terminate on receipt of SIGTERM, keeping KDbg
    running for 20 seconds. This was fixed.
* Tue Dec  3 2013 pgajdos@suse.com
- use png_fix_dir macro [bnc#852862]
* Mon Nov 11 2013 wbauer@tmo.at
- Update to 2.5.4:
  * Source file names with international characters are handled better.
  * When an executable is loaded, GDBs of different vintage print different
    text, some of which were treated as error text incorrectly, leading to
    failed debugging sessions. More of these texts are now ignored.
  * Variables pointing to some global variable lacked the ability to be
    expanded with recent GDBs.
  * Parsing of string values residing in global variables was fixed.
- Removed opensuse-gdb.diff, it's included upstream now
* Wed Apr  3 2013 wbauer@tmo.at
- remove debug-run.png icon from package as it is already included
  in oxygen-icon-theme. (caused a file conflict)
* Mon Apr  1 2013 wbauer@tmo.at
- Update to 2.5.3
  * Duplicated and <MULTIPLE> breakpoints do not increase the list of
    breakpoints each time a session is started
  * Communication with a localized GDB works; this is achieved by setting
    LC_ALL=C, which is also propagated to the program being debugged. If
    the program needs a different locale, set it in Execution->Arguments,
    page Environment.
  * Fixed a crash in the memory window
  * Updates of the Russian and Croatian translations.
* Sun Jan  6 2013 wbauer@tmo.at
- adapt opensuse-gdb.diff to slightly different gdb output in case of
  a missing debuginfo-package on 12.3
* Wed Nov  7 2012 wbauer@tmo.at
- Update to 2.5.2
  - Support for GDB 7.5.
  - More of GDB's output is recognized in some corner cases
  - The thread list parser introduced in 2.5.1 sometimes stripped two letters
    from the function name.
- Added opensuse-gdb.diff: ignore messages about debuginfo-packages from
  openSUSE's gdb (bnc#784634)
* Tue Apr  3 2012 cgiboudeaux@gmx.com
- Update to 2.5.1
  - .hpp files undergo syntax highlighting.
  - Keys j and k can be used to move the cursor position in the source code.
  - Cooperation with newer GDB (7.2 and 7.3) is improved:
  * wchar_t strings as printed by GDB 7.2 are recognized;
  * the thread list was missing with GDB 7.3;
  * program exit was not detected (also GDB 7.3).
  - Enum values in anonymous namespaces are now recognized.
* Sat Oct  8 2011 toddrme2178@gmail.com
- Moved all documentation to the documentation package
  (fix for RPMLINT warning)
- Cleaned up spec file formatting
* Thu Sep 22 2011 idonmez@suse.com
- Seperate doc package & fix build
* Wed Sep 21 2011 tittiatcoke@gmail.com
- 2.5.0 release:
  * This release is based on KDE4 and Qt4.
  - A number of icons were exchanged with Oxygen icons. These are
    not part of KDbg's source code.
  - Session state per debugged program is now stored in a section
    in $KDEHOME rather than in a .kdbgrc file in the program's
    directory. This allows to debug programs that are located in
    unwritable directories. But this also means that earlier
    session information is disregarded.
  - More accurate parsing of GDB responses of various commands
    fixed bugs in certain areas, in particular, temporary
    breakpoints, register values, truncated struct values,
    disassembly (again).
  - "View Code" from the breakpoint list can open the source code
    in more cases.
* Thu Jul  8 2010 beineri@opensuse.org
- 2.2.2 bugfix release:
  * An error message was shown instead of assembler code when
    gdb 7.1 was used.
* Sun Apr 11 2010 beineri@opensuse.org
- 2.2.1 bugfix release:
  * A crash could occur when the variable window was updated.
  * A crash when command line switch -a was used together with a
    non-existing executable name.
  * Syntax highlighting was applied to all files, not just C/C++.
  * The display was incorrect when a file was reloaded that had
    disassembly lines visible.
  * Some minor documentation fixes.
* Wed Sep  9 2009 beineri@opensuse.org
- 2.2.0 update, bugfixes and following new features:
  * Source code windows have now a tab attached, which makes
    switching source files much easier.
  * Source code windows now show line numbers at the left.
  * There are now "Find Next" and "Find Previous" commands with
    shortcuts F3 and Shift+F3.
  * Improved support of template types in the type tables (which
    are used to show structure members next to a structure variable).
    Notably, the number of elements in STL and Qt collection classes
    are shown.
  * Arguments for the debugged program can be passed on command line.
* Fri May 29 2009 llunak@suse.cz
- build with gcc 4.4
* Sat Apr 25 2009 beineri@opensuse.org
- reviewed changes
* Mon Mar 30 2009 cmorve69@yahoo.es
- 2.1.1 update
* Wed Dec 19 2007 stbinner@suse.de
- update to final 2.1 version, only translation updates
* Wed Sep 26 2007 stbinner@suse.de
- 2.1.0rc1 update
* Mon Dec 18 2006 stbinner@suse.de
- 2.0.5 update
  * Appearance of the main window for first-time users was improved.
  * Improve file handling when the srcdir != builddir.
  * Show value popups for members of 'this'.
  * Allow user to give redirections in Program Arguments dialog.
* Mon May 29 2006 stbinner@suse.de
- 2.0.4 update
  * Fixed encoding of the Czech translation
  * Added support for QString in Qt4's debug libraries.
  * Fixed that the debugger window really comes to the foreground
    and receives the focus when the debuggee stops at a breakpoint,
    when this option is on
* Fri Jan 27 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Jan 25 2006 dmueller@suse.de
- 2.0.3 update (bugfix only):
  * Fix parsing of stack traces with operator<<,operator>>
* Wed Nov 30 2005 stbinner@suse.de
- 2.0.2 update
* Wed Oct 26 2005 stbinner@suse.de
- 2.0.1 update
* Mon Jul 18 2005 dmueller@suse.de
- 2.0.0 update
* Wed May 25 2005 adrian@suse.de
- fix build with new gcc
* Thu Feb 17 2005 ro@suse.de
- fixed file list
* Tue Nov  2 2004 coolo@suse.de
- fixing norwegian translations
* Thu Aug  5 2004 coolo@suse.de
- updated to 1.2.10
* Sat Jul 31 2004 coolo@suse.de
- fixing desktop file
* Mon May 10 2004 adrian@suse.de
- add patch to handle nptl based gdb output
  (patch from debian)
* Thu Apr 15 2004 coolo@suse.de
- build without unsermake
* Wed Feb 25 2004 adrian@suse.de
- update to version 1.2.9
* Wed Sep  3 2003 adrian@suse.de
- fix Categories
* Mon Jul 28 2003 adrian@suse.de
- add Categories
* Thu Jun 12 2003 coolo@suse.de
- use %%find_lang
* Fri Jan 10 2003 coolo@suse.de
- update to 1.2.6
* Tue Nov 19 2002 coolo@suse.de
- use update_admin
* Thu May 23 2002 coolo@suse.de
- adding admin tar ball and use common_options
* Mon May  6 2002 coolo@suse.de
- buildroot fixes
- corrected po makefile for updated admin dir
* Fri Apr 26 2002 coolo@suse.de
- fixing admin directory.
* Thu Apr 25 2002 coolo@suse.de
- fix build for ia64
* Fri Apr 12 2002 adrian@suse.de
- update to version 1.2.5 (for KDE 3 now)
- automake 1.6 fixes
- gcc 3 fixes
* Mon Mar 18 2002 adrian@suse.de
- fix broken encodings in .desktop file
* Thu Jan  3 2002 adrian@suse.de
- update to version 1.2.3
* Wed Nov 14 2001 ro@suse.de
- create dirs first
* Wed Nov 14 2001 ro@suse.de
- use kde2-devel-packages in neededforbuild
* Tue Aug 28 2001 adrian@suse.de
- new version 1.2.2
* Mon Aug 13 2001 ro@suse.de
- changed neededforbuild <sp_libs> to <sp-devel>
* Tue Aug  7 2001 adrian@suse.de
- autoconf 2.52 fixes
* Sun Jul 15 2001 adrian@suse.de
- new version 1.2.1
* Thu Jun 21 2001 adrian@suse.de
- autoconf 2.50 fixes
* Tue Mar 27 2001 ro@suse.de
- changed neededforbuild <docbkdsl> to <docbook-dsssl-stylesheets>
* Sun Mar 18 2001 ro@suse.de
- fixed neededforbuild
* Tue Mar 13 2001 ro@suse.de
- changed neededforbuild <docbk30> to <docbook_3>
* Thu Mar  1 2001 ro@suse.de
- added fam to neededforbuild
* Mon Jan  1 2001 adrian@suse.de
- update to stable version 1.2.0
* Fri Nov 17 2000 ro@suse.de
- fixed neededforbuild: += libmng-devel
* Tue Nov 14 2000 adrian@suse.de
- New Version 1.1.7 Beta 1 (KDE 2)
* Wed Aug 23 2000 adrian@suse.de
- New Version 1.1.5
* Mon Jun 19 2000 adrian@suse.de
- New version 1.1.4
* Thu Jun  8 2000 adrian@suse.de
- New version 1.1.3
* Thu May 25 2000 adrian@suse.de
- Added group tag, suse_update_config and new file list
* Thu May 25 2000 adrian@suse.de
- Spec file created from kdbg-1.1.2.tar.gz by autospec
* Fri Apr 21 2000 adrian@suse.de
- New version 1.1.2
* Wed Apr 12 2000 adrian@suse.de
- New version 1.1.1
* Thu Mar 30 2000 adrian@suse.de
- delete the kbase from neededforbuild
* Sat Mar  4 2000 adrian@suse.de
- New version 1.0.2
* Thu Nov 25 1999 kettner@suse.de
- New version 1.0.1
* Fri Nov 19 1999 kettner@suse.de
- New version 1.0.0
* Fri Oct 15 1999 kettner@suse.de
- New version 1.0beta3
* Fri Sep 17 1999 kettner@suse.de
- Reinserted old # Commandline: line.
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Fri Aug 27 1999 kettner@suse.de
- New version 1.0beta2
  - Moved menu item to Applications.
* Thu Aug  5 1999 kettner@suse.de
- New version 1.0beta1
* Thu Jul  1 1999 kettner@suse.de
- New version 0.3.1
* Wed May 19 1999 kettner@suse.de
- Recreated spec file with new autospec
* Wed Apr 14 1999 kettner@suse.de
- autospec created new spec file from kdbg-0.3.0.tar.gz
* Wed Mar 31 1999 bs@suse.de
- don't use lx_hack for build
  Wed Mar 17 22:24:07 MET 1999 - autospec
- Recreated spec file from kdbg-0.2.5.tar.gz using autospec script by kettner@suse.de
